@@ -1,16 +1,11 @@
-# -*- coding=utf-8 -*-
-from __future__ import absolute_import, print_function
-
 import logging
 import warnings
 
-import setuptools
-
 from .models.lockfile import Lockfile
 from .models.pipfile import Pipfile
 from .models.requirements import Requirement
 
-__version__ = "1.6.7"
+__version__ = "2.0.0"
 
 
 logger = logging.getLogger(__name__)
